@@ -161,7 +161,7 @@ class Task:
         """
         return Task.__get_command(self)
 
-    def execute(self, timeout_hour=-1) -> SimpleNamespace:
+    def execute(self, timeout_hour=-1) -> subprocess.CompletedProcess:
         """
         Execute the task
         :return:
@@ -185,11 +185,20 @@ class Task:
 
         try:
             results = subprocess.run(formatted_command, shell=True, text=True,
-                                     stdout=stdout, stderr=stderr,
+                                     stdout=stdout, stderr=stderr, check=True,
                                      **kwargs)
+
+        except subprocess.SubprocessError as exception:
+            results = exception
+
         finally:
             stdout.close()
             stderr.close()
+            stdout.join()
+            stderr.join()
+
+        results.stdout = stdout.text()
+        results.stderr = stderr.text()
 
         execution_time = datetime.timedelta(seconds=time.time() - execution_start)
 
@@ -197,7 +206,10 @@ class Task:
                            f'- Execution time: {execution_time} ({execution_time.total_seconds()} s)')
         self.__logger.info(f'Exit code: {results.returncode}')
 
-        return SimpleNamespace(exit_code=results.returncode, stdout=stdout.text(), stderr=stderr.text())
+        if isinstance(results, subprocess.SubprocessError):
+            raise results
+
+        return results
 
     @classmethod
     def from_dict(cls, dictionary: Dict) -> 'Task':
